@@ -328,3 +328,19 @@ class CategoryFeed(Feed):
 
     # XXX it might be possible to generate a title and description here.
 
+
+def breadcrumbs(*args):
+    yield ('/', _('Home'))
+    # XXX We could automatically navigate items here using a parent meta type.
+    for model in args:
+        if type(model) is str:
+            yield ("", _(model))
+        elif isinstance(model, tuple):
+            yield (reverse(model[0]), _(model[1]))
+        elif model is None:
+            pass
+        elif not hasattr(model, "get_absolute_url"):
+            raise ValueError("Refusing the make '%s' into a breadcrumb!" % str(model))
+        else:
+            yield (model.get_absolute_url(), unicode(model))
+
